TemporalArrowConvert

Trait TemporalArrowConvert 

trait TemporalArrowConvert<ArrowNative>: Sized {
    // Required methods
    fn try_from_arrow_with_time_unit(
        value: ArrowNative,
        time_unit: TimeUnit,
    ) -> Result<Self, ArrayError>;
    fn into_arrow_with_time_unit(self, time_unit: TimeUnit) -> ArrowNative;
}
Converts a RisingWave temporal scalar to and from Arrow’s physical primitive value using an Arrow time unit.

Required Methods

fn try_from_arrow_with_time_unit( value: ArrowNative, time_unit: TimeUnit, ) -> Result<Self, ArrayError>

fn into_arrow_with_time_unit(self, time_unit: TimeUnit) -> ArrowNative

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl TemporalArrowConvert<i32> for Time

Arrow Time32 arrays are defined only for second and millisecond units.

Source

impl TemporalArrowConvert<i64> for Time

Arrow Time64 arrays are defined only for microsecond and nanosecond units.

RisingWave’s time is microsecond-precision, so nanoseconds are truncated.

Source

impl TemporalArrowConvert<i64> for Timestamp

Source

impl TemporalArrowConvert<i64> for Timestamptz