pub struct IcebergCreateTableArrowConvert {
next_field_id: RefCell<u32>,
}Expand description
Iceberg sink with create_table_if_not_exists option will use this struct to convert the
iceberg data type to arrow data type.
Specifically, it will add the field id to the arrow field metadata, because iceberg-rust need the field id to be set.
Note: this is different from IcebergArrowConvert, which is used to read from/write to
an existing iceberg table. In that case, we just need to make sure the data is compatible to the existing schema.
But to create a new table, we need to meet more requirements of iceberg.
Fields
next_field_id: RefCell<u32>Implementations
Sourceimpl IcebergCreateTableArrowConvert
impl IcebergCreateTableArrowConvert
pub fn to_arrow_field( &self, name: &str, data_type: &DataType, ) -> Result<Field, ArrayError>
fn add_field_id(&self, arrow_field: &mut Field)