pub struct MetaDeveloperConfig {Show 24 fields
pub cached_traces_num: u32,
pub cached_traces_memory_limit_bytes: usize,
pub enable_trivial_move: bool,
pub enable_check_task_level_overlap: bool,
pub max_trivial_move_task_count_per_loop: usize,
pub max_get_task_probe_times: usize,
pub actor_cnt_per_worker_parallelism_soft_limit: usize,
pub actor_cnt_per_worker_parallelism_hard_limit: usize,
pub hummock_time_travel_sst_info_fetch_batch_size: usize,
pub hummock_time_travel_sst_info_insert_batch_size: usize,
pub time_travel_vacuum_interval_sec: u64,
pub time_travel_vacuum_max_version_count: Option<u32>,
pub hummock_time_travel_epoch_version_insert_batch_size: usize,
pub hummock_time_travel_delta_fetch_batch_size: usize,
pub hummock_gc_history_insert_batch_size: usize,
pub hummock_time_travel_filter_out_objects_batch_size: usize,
pub hummock_time_travel_filter_out_objects_v1: bool,
pub hummock_time_travel_filter_out_objects_list_version_batch_size: usize,
pub hummock_time_travel_filter_out_objects_list_delta_batch_size: usize,
pub compute_client_config: RpcClientConfig,
pub stream_client_config: RpcClientConfig,
pub frontend_client_config: RpcClientConfig,
pub table_change_log_insert_batch_size: u64,
pub table_change_log_delete_batch_size: u64,
}Expand description
The subsections [meta.developer].
It is put at MetaConfig::developer.
Fields
cached_traces_num: u32The number of traces to be cached in-memory by the tracing collector embedded in the meta node.
cached_traces_memory_limit_bytes: usizeThe maximum memory usage in bytes for the tracing collector embedded in the meta node.
enable_trivial_move: boolCompaction picker config
enable_check_task_level_overlap: boolmax_trivial_move_task_count_per_loop: usizemax_get_task_probe_times: usizeactor_cnt_per_worker_parallelism_soft_limit: usizeMax number of actor allowed per parallelism (default = 100). CREATE MV/Table will be noticed when the number of actors exceeds this limit.
actor_cnt_per_worker_parallelism_hard_limit: usizeMax number of actor allowed per parallelism (default = 400). CREATE MV/Table will be rejected when the number of actors exceeds this limit.
hummock_time_travel_sst_info_fetch_batch_size: usizeMax number of SSTs fetched from meta store per SELECT, during time travel Hummock version replay.
hummock_time_travel_sst_info_insert_batch_size: usizeMax number of SSTs inserted into meta store per INSERT, during time travel metadata writing.
time_travel_vacuum_interval_sec: u64time_travel_vacuum_max_version_count: Option<u32>hummock_time_travel_epoch_version_insert_batch_size: usizeMax number of epoch-to-version inserted into meta store per INSERT, during time travel metadata writing.
hummock_time_travel_delta_fetch_batch_size: usizeMax number of version deltas fetched from meta store per SELECT, during time travel metadata vacuum.
hummock_gc_history_insert_batch_size: usizehummock_time_travel_filter_out_objects_batch_size: usizehummock_time_travel_filter_out_objects_v1: boolhummock_time_travel_filter_out_objects_list_version_batch_size: usizehummock_time_travel_filter_out_objects_list_delta_batch_size: usizecompute_client_config: RpcClientConfigstream_client_config: RpcClientConfigfrontend_client_config: RpcClientConfigtable_change_log_insert_batch_size: u64table_change_log_delete_batch_size: u64Implementations