pub enum FileCacheRuntimeConfig {
Disabled,
Unified(FileCacheTokioRuntimeConfig),
Separated {
read_runtime_options: FileCacheTokioRuntimeConfig,
write_runtime_options: FileCacheTokioRuntimeConfig,
},
}Variants
Disabled
Use the runtime that creates the file cache.
Unified(FileCacheTokioRuntimeConfig)
Use one dedicated runtime for all file cache tasks.
Separated
Legacy configuration for separate read and write runtimes.
Foyer 0.22 uses one spawner, so this configuration is no longer supported.
Fields

read_runtime_options: FileCacheTokioRuntimeConfig
write_runtime_options: FileCacheTokioRuntimeConfigTrait Implementations
Sourceimpl Clone for FileCacheRuntimeConfig
impl Clone for FileCacheRuntimeConfig
Sourcefn clone(&self) -> FileCacheRuntimeConfig
fn clone(&self) -> FileCacheRuntimeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileCacheRuntimeConfig
impl Debug for FileCacheRuntimeConfig
Sourceimpl<'de> Deserialize<'de> for FileCacheRuntimeConfig
impl<'de> Deserialize<'de> for FileCacheRuntimeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more