pub struct CacheRefillConfig {
pub meta_refill_concurrency: usize,
pub data_refill_levels: Vec<u32>,
pub timeout_ms: u64,
pub concurrency: usize,
pub unit: usize,
pub threshold: f64,
pub recent_filter_shards: usize,
pub recent_filter_layers: usize,
pub recent_filter_rotate_interval_ms: usize,
pub skip_recent_filter: bool,
pub skip_inheritance_filter: bool,
pub unrecognized: Unrecognized<Self>,
}Fields
meta_refill_concurrency: usizeInflight meta cache refill tasks limit.
0 for unlimited.
data_refill_levels: Vec<u32>SSTable levels to refill.
timeout_ms: u64Cache refill maximum timeout to apply version delta.
concurrency: usizeInflight data cache refill tasks.
unit: usizeBlock count that a data cache refill request fetches.
threshold: f64Data cache refill unit admission ratio.
Only unit whose blocks are admitted above the ratio will be refilled.
recent_filter_shards: usizeRecent filter layer shards.
recent_filter_layers: usizeRecent filter layer count.
recent_filter_rotate_interval_ms: usizeRecent filter layer rotate interval.
skip_recent_filter: boolSkip checking recent filter on data refill.
This option is suitable for a single compute node or debugging.
skip_inheritance_filter: boolSkip checking inheritance filter on data refill.
The inheritance filter only runs after recent-filter admission, so this
option has no effect when skip_recent_filter is enabled.
This option is suitable for a single compute node or debugging.
unrecognized: Unrecognized<Self>Implementations