pub struct ObjectStoreConfig {
pub set_atomic_write_dir: bool,
pub retry: ObjectStoreRetryConfig,
pub s3: S3ObjectStoreConfig,
pub req_concurrency_limit: usize,
pub http_concurrent_limit: usize,
pub opendal_upload_concurrency: usize,
pub opendal_writer_abort_on_err: bool,
pub upload_part_size: usize,
}Expand description
The subsections [storage.object_store].
Fields
set_atomic_write_dir: boolretry: ObjectStoreRetryConfigRetry and timeout configuration Description retry strategy driven by exponential back-off Exposes the timeout and retries of each Object store interface. Therefore, the total timeout for each interface is determined based on the interface’s timeout/retry configuration and the exponential back-off policy.
s3: S3ObjectStoreConfigSome special configuration of S3 Backend
req_concurrency_limit: usizeMaximum number of concurrent object store requests (read, streaming_read, metadata, etc.).
0 means unlimited. When set to a positive value, a semaphore will be used to limit
the number of in-flight requests to the object store, preventing HTTP connection pool
contention under high concurrency.
http_concurrent_limit: usizeMaximum number of concurrent HTTP requests used by the OpenDAL GCS backend.
0 means unlimited.
opendal_upload_concurrency: usizeopendal_writer_abort_on_err: boolupload_part_size: usizeImplementations
Sourceimpl ObjectStoreConfig
impl ObjectStoreConfig
pub fn set_atomic_write_dir(&mut self)