pub struct ObjectStoreRetryConfig {Show 19 fields
pub req_backoff_interval_ms: u64,
pub req_backoff_max_delay_ms: u64,
pub req_backoff_factor: u64,
pub upload_attempt_timeout_ms: u64,
pub upload_retry_attempts: usize,
pub streaming_upload_attempt_timeout_ms: u64,
pub streaming_upload_retry_attempts: usize,
pub read_attempt_timeout_ms: u64,
pub read_retry_attempts: usize,
pub streaming_read_attempt_timeout_ms: u64,
pub streaming_read_retry_attempts: usize,
pub metadata_attempt_timeout_ms: u64,
pub metadata_retry_attempts: usize,
pub delete_attempt_timeout_ms: u64,
pub delete_retry_attempts: usize,
pub delete_objects_attempt_timeout_ms: u64,
pub delete_objects_retry_attempts: usize,
pub list_attempt_timeout_ms: u64,
pub list_retry_attempts: usize,
}Fields
req_backoff_interval_ms: u64Given a base duration for retry strategy in milliseconds.
req_backoff_max_delay_ms: u64The max delay interval for the retry strategy. No retry delay will be longer than this Duration.
req_backoff_factor: u64A multiplicative factor that will be applied to the exponential back-off retry delay.
upload_attempt_timeout_ms: u64Maximum timeout for upload operation
upload_retry_attempts: usizeTotal counts of upload operation retries
streaming_upload_attempt_timeout_ms: u64Maximum timeout for streaming_upload_init and streaming_upload
streaming_upload_retry_attempts: usizeTotal counts of streaming_upload operation retries
read_attempt_timeout_ms: u64Maximum timeout for read operation
read_retry_attempts: usizeTotal counts of read operation retries
streaming_read_attempt_timeout_ms: u64Maximum timeout for streaming_read_init and streaming_read operation
streaming_read_retry_attempts: usizeTotal counts of streaming_read operation retries
metadata_attempt_timeout_ms: u64Maximum timeout for metadata operation
metadata_retry_attempts: usizeTotal counts of metadata operation retries
delete_attempt_timeout_ms: u64Maximum timeout for delete operation
delete_retry_attempts: usizeTotal counts of delete operation retries
delete_objects_attempt_timeout_ms: u64Maximum timeout for delete_object operation
delete_objects_retry_attempts: usizeTotal counts of delete_object operation retries
list_attempt_timeout_ms: u64Maximum timeout for list operation
list_retry_attempts: usizeTotal counts of list operation retries