pub enum CacheRefillPolicy {
Enabled,
Disabled,
Streaming,
Serving,
Both,
}Variants
Enabled
Enable normal cache refill for the table.
Disabled
Disable cache refill for the table.
Streaming
Enable cache refill optimized for streaming workloads for this table.
Serving
Enable cache refill optimized for serving workloads for this table.
Both
Enable cache refill optimized for both streaming and serving workloads for this table.
Implementations
Sourceimpl CacheRefillPolicy
impl CacheRefillPolicy
pub fn to_protobuf(self) -> PbCacheRefillPolicy
pub fn from_protobuf(pb: PbCacheRefillPolicy) -> Option<Self>
Sourcepub fn is_unscoped_enabled(self) -> bool
pub fn is_unscoped_enabled(self) -> bool
Legacy/default table-level allow policy. Normal refill is not scoped by streaming or serving vnode ownership under this policy.
pub fn is_streaming_scoped(self) -> bool
pub fn is_serving_scoped(self) -> bool