pub struct StreamingConfig {
pub in_flight_barrier_nums: usize,
pub snapshot_backfill_finish_max_lagged_barriers: usize,
pub snapshot_backfill_barrier_amplification_factor: usize,
pub actor_runtime_worker_threads_num: Option<usize>,
pub async_stack_trace: AsyncStackTraceOption,
pub developer: StreamingDeveloperConfig,
pub unique_user_stream_errors: usize,
pub unsafe_disable_strict_consistency: bool,
pub unrecognized: Unrecognized<Self>,
}Expand description
The section [streaming] in risingwave.toml.
Fields
in_flight_barrier_nums: usizeThe maximum number of pending barriers in each partial graph. Pending barriers include in-flight, collected but not committed, and currently completing barriers.
snapshot_backfill_finish_max_lagged_barriers: usizeThe maximum number of lagged barriers allowed when merging a snapshot backfill job into the database graph.
snapshot_backfill_barrier_amplification_factor: usizeThe multiplier applied to in_flight_barrier_nums when limiting pending barriers in a
snapshot backfill partial graph. A value of 0 is treated as 1.
actor_runtime_worker_threads_num: Option<usize>The thread number of the streaming actor runtime in the compute node. The default value is
decided by tokio.
async_stack_trace: AsyncStackTraceOptionEnable async stack tracing through await-tree for risectl.
developer: StreamingDeveloperConfigunique_user_stream_errors: usizeMax unique user stream errors per actor
unsafe_disable_strict_consistency: boolDisable strict stream consistency checks.
unrecognized: Unrecognized<Self>Implementations
Sourceimpl StreamingConfig
impl StreamingConfig
Sourcepub fn unrecognized_keys(&self) -> impl Iterator<Item = String>
pub fn unrecognized_keys(&self) -> impl Iterator<Item = String>
Returns the dot-separated keys of all unrecognized fields, including those in developer section.