pub struct SystemConfig {Show 18 fields
pub barrier_interval_ms: Option<u32>,
pub checkpoint_frequency: Option<u64>,
pub sstable_size_mb: Option<u32>,
pub parallel_compact_size_mb: Option<u32>,
pub block_size_kb: Option<u32>,
pub bloom_false_positive: Option<f64>,
pub state_store: Option<String>,
pub data_directory: Option<String>,
pub backup_storage_url: Option<String>,
pub backup_storage_directory: Option<String>,
pub max_concurrent_creating_streaming_jobs: Option<u32>,
pub pause_on_next_bootstrap: Option<bool>,
pub enable_tracing: Option<bool>,
pub use_new_object_prefix_strategy: Option<bool>,
pub license_key: Option<LicenseKey>,
pub time_travel_retention_ms: Option<u64>,
pub per_database_isolation: Option<bool>,
pub enforce_secret: Option<bool>,
}Expand description
The section [system] in risingwave.toml. All these fields are used to initialize the system
parameters persisted in Meta store. Most fields are for testing purpose only and should not be
documented.
Fields
barrier_interval_ms: Option<u32>The interval of periodic barrier.
checkpoint_frequency: Option<u64>There will be a checkpoint for every n barriers.
sstable_size_mb: Option<u32>Target size of the Sstable.
parallel_compact_size_mb: Option<u32>The size of parallel task for one compact/flush job.
block_size_kb: Option<u32>Size of each block in bytes in SST.
bloom_false_positive: Option<f64>DEPRECATED: Bloom filter is no longer a supported SST filter implementation. This field is kept for backward compatibility and no longer controls whether SST filters are emitted.
state_store: Option<String>URL for the state store
data_directory: Option<String>Remote directory for storing data and metadata objects.
backup_storage_url: Option<String>Remote storage url for storing snapshots.
backup_storage_directory: Option<String>Remote directory for storing snapshots.
max_concurrent_creating_streaming_jobs: Option<u32>Max number of concurrent creating streaming jobs.
pause_on_next_bootstrap: Option<bool>Whether to pause all data sources on next bootstrap.
enable_tracing: Option<bool>Whether to enable distributed tracing.
use_new_object_prefix_strategy: Option<bool>Whether to split object prefix.
license_key: Option<LicenseKey>The license key to activate enterprise features.
time_travel_retention_ms: Option<u64>The data retention period for time travel.
per_database_isolation: Option<bool>Whether per database isolation is enabled
enforce_secret: Option<bool>Whether to enforce secret on cloud.
Implementations
Sourceimpl SystemConfig
impl SystemConfig
Sourceimpl SystemConfig
impl SystemConfig
pub fn into_init_system_params(self) -> SystemParams