IsSingleton

Trait IsSingleton 

pub trait IsSingleton {
    // Required method
    fn is_singleton(&self) -> bool;
}
A trait for checking whether a table/fragment is a singleton.

Required Methods

fn is_singleton(&self) -> bool

Returns true if the table/fragment is a singleton.

By singleton, we mean that all data read from or written to the storage belongs to the only SINGLETON_VNODE. This must be consistent with the behavior of TableDistribution. As a result, the vnode_count of such table/fragment can be 1.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IsSingleton for StorageTableDesc

Source

impl IsSingleton for Table

Implementors