VnodeMappingItem

Trait VnodeMappingItem 

pub trait VnodeMappingItem {
    type Item: Copy + Ord + Hash + Debug;
}
Trait for items that can be used as keys in VnodeMapping.

Required Associated Types

type Item: Copy + Ord + Hash + Debug

The type of the item.

Currently, there are two types of items: WorkerSlotId and ActorId. We don’t use them directly as the generic parameter because they’re the same type aliases.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors