pub enum TxnMsg {
Begin(TxnId),
Data(TxnId, StreamChunk),
End(TxnId, Option<Sender<Epoch>>),
Rollback(TxnId),
}Variants
Implementations
Sourceimpl TxnMsg
impl TxnMsg
Sourcepub fn as_begin_mut(&mut self) -> Option<&mut TxnId>
pub fn as_begin_mut(&mut self) -> Option<&mut TxnId>
Optionally returns mutable references to the inner fields if this is a TxnMsg::Begin, otherwise None
Sourcepub fn as_begin(&self) -> Option<&TxnId>
pub fn as_begin(&self) -> Option<&TxnId>
Optionally returns references to the inner fields if this is a TxnMsg::Begin, otherwise None
Sourcepub fn into_begin(self) -> Result<TxnId, Self>
pub fn into_begin(self) -> Result<TxnId, Self>
Returns the inner fields if this is a TxnMsg::Begin, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_begin_unchecked(self) -> TxnId
pub unsafe fn into_begin_unchecked(self) -> TxnId
Unchecked return of the inner fields of TxnMsg::Begin.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_begin_unchecked(&self) -> &TxnId
pub unsafe fn as_begin_unchecked(&self) -> &TxnId
Unchecked reference of the inner fields of TxnMsg::Begin.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_begin_mut_unchecked(&mut self) -> &mut TxnId
pub unsafe fn as_begin_mut_unchecked(&mut self) -> &mut TxnId
Unchecked mutable reference of the inner fields of TxnMsg::Begin.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn as_data_mut(&mut self) -> Option<(&mut TxnId, &mut StreamChunk)>
pub fn as_data_mut(&mut self) -> Option<(&mut TxnId, &mut StreamChunk)>
Optionally returns mutable references to the inner fields if this is a TxnMsg::Data, otherwise None
Sourcepub fn as_data(&self) -> Option<(&TxnId, &StreamChunk)>
pub fn as_data(&self) -> Option<(&TxnId, &StreamChunk)>
Optionally returns references to the inner fields if this is a TxnMsg::Data, otherwise None
Sourcepub fn into_data(self) -> Result<(TxnId, StreamChunk), Self>
pub fn into_data(self) -> Result<(TxnId, StreamChunk), Self>
Returns the inner fields if this is a TxnMsg::Data, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_data_unchecked(self) -> (TxnId, StreamChunk)
pub unsafe fn into_data_unchecked(self) -> (TxnId, StreamChunk)
Unchecked return of the inner fields of TxnMsg::Data.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_data_unchecked(&self) -> (&TxnId, &StreamChunk)
pub unsafe fn as_data_unchecked(&self) -> (&TxnId, &StreamChunk)
Unchecked reference of the inner fields of TxnMsg::Data.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_data_mut_unchecked(&mut self) -> (&mut TxnId, &mut StreamChunk)
pub unsafe fn as_data_mut_unchecked(&mut self) -> (&mut TxnId, &mut StreamChunk)
Unchecked mutable reference of the inner fields of TxnMsg::Data.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn as_end_mut(&mut self) -> Option<(&mut TxnId, &mut Option<Sender<Epoch>>)>
pub fn as_end_mut(&mut self) -> Option<(&mut TxnId, &mut Option<Sender<Epoch>>)>
Optionally returns mutable references to the inner fields if this is a TxnMsg::End, otherwise None
Sourcepub fn as_end(&self) -> Option<(&TxnId, &Option<Sender<Epoch>>)>
pub fn as_end(&self) -> Option<(&TxnId, &Option<Sender<Epoch>>)>
Optionally returns references to the inner fields if this is a TxnMsg::End, otherwise None
Sourcepub fn into_end(self) -> Result<(TxnId, Option<Sender<Epoch>>), Self>
pub fn into_end(self) -> Result<(TxnId, Option<Sender<Epoch>>), Self>
Returns the inner fields if this is a TxnMsg::End, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_end_unchecked(self) -> (TxnId, Option<Sender<Epoch>>)
pub unsafe fn into_end_unchecked(self) -> (TxnId, Option<Sender<Epoch>>)
Unchecked return of the inner fields of TxnMsg::End.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_end_unchecked(&self) -> (&TxnId, &Option<Sender<Epoch>>)
pub unsafe fn as_end_unchecked(&self) -> (&TxnId, &Option<Sender<Epoch>>)
Unchecked reference of the inner fields of TxnMsg::End.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_end_mut_unchecked(
&mut self,
) -> (&mut TxnId, &mut Option<Sender<Epoch>>)
pub unsafe fn as_end_mut_unchecked( &mut self, ) -> (&mut TxnId, &mut Option<Sender<Epoch>>)
Unchecked mutable reference of the inner fields of TxnMsg::End.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn is_rollback(&self) -> bool
pub fn is_rollback(&self) -> bool
Returns true if this is a TxnMsg::Rollback, otherwise false
Sourcepub fn as_rollback_mut(&mut self) -> Option<&mut TxnId>
pub fn as_rollback_mut(&mut self) -> Option<&mut TxnId>
Optionally returns mutable references to the inner fields if this is a TxnMsg::Rollback, otherwise None
Sourcepub fn as_rollback(&self) -> Option<&TxnId>
pub fn as_rollback(&self) -> Option<&TxnId>
Optionally returns references to the inner fields if this is a TxnMsg::Rollback, otherwise None
Sourcepub fn into_rollback(self) -> Result<TxnId, Self>
pub fn into_rollback(self) -> Result<TxnId, Self>
Returns the inner fields if this is a TxnMsg::Rollback, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_rollback_unchecked(self) -> TxnId
pub unsafe fn into_rollback_unchecked(self) -> TxnId
Unchecked return of the inner fields of TxnMsg::Rollback.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_rollback_unchecked(&self) -> &TxnId
pub unsafe fn as_rollback_unchecked(&self) -> &TxnId
Unchecked reference of the inner fields of TxnMsg::Rollback.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_rollback_mut_unchecked(&mut self) -> &mut TxnId
pub unsafe fn as_rollback_mut_unchecked(&mut self) -> &mut TxnId
Unchecked mutable reference of the inner fields of TxnMsg::Rollback.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourceimpl TxnMsg
impl TxnMsg
pub fn txn_id(&self) -> TxnId
pub fn as_stream_chunk(&self) -> Option<&StreamChunk>