Timestamptz

Struct Timestamptz 

#[repr(transparent)]
pub struct Timestamptz(i64);
Timestamp with timezone.

Tuple Fields

0: i64

Implementations

Source

impl Timestamptz

pub const MIN: Self

pub fn from_secs(timestamp_secs: i64) -> Option<Self>

Creates a Timestamptz from seconds. Returns None if the given timestamp is out of range.

pub fn from_millis(timestamp_millis: i64) -> Option<Self>

Creates a Timestamptz from milliseconds. Returns None if the given timestamp is out of range.

pub fn from_micros(timestamp_micros: i64) -> Self

Creates a Timestamptz from microseconds.

pub fn from_nanos(timestamp_nanos: i64) -> Option<Self>

Creates a Timestamptz from microseconds.

pub fn timestamp_micros(&self) -> i64

Returns the number of non-leap-microseconds since January 1, 1970 UTC.

pub fn timestamp_millis(&self) -> i64

Returns the number of non-leap-milliseconds since January 1, 1970 UTC.

pub fn timestamp_nanos(&self) -> Option<i64>

Returns the number of non-leap-nanosseconds since January 1, 1970 UTC.

pub fn timestamp(&self) -> i64

Returns the number of non-leap seconds since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”).

pub fn timestamp_subsec_nanos(&self) -> u32

Returns the number of nanoseconds since the last second boundary.

pub fn to_datetime_utc(self) -> DateTime<Utc>

pub fn to_datetime_in_zone(self, tz: Tz) -> DateTime<Tz>

pub fn lookup_time_zone(time_zone: &str) -> Result<Tz, String>

pub fn from_protobuf(cur: &mut Cursor<&[u8]>) -> ArrayResult<Timestamptz>

pub fn to_protobuf(self, output: &mut impl Write) -> ArrayResult<usize>