enum ColumnMapping {
Small(SmallVec<[i32; 8]>),
Large(HashMap<i32, usize>),
}Expand description
A mapping from column id to the index of the column in the schema.
Variants
Small(SmallVec<[i32; 8]>)
For small number of columns, use linear search with SmallVec. This ensures no heap allocation.
Large(HashMap<i32, usize>)
For larger number of columns, build a HashMap for faster lookup.
Implementations