FrontendConfig

Struct FrontendConfig 

pub struct FrontendConfig {
    pub max_total_query_size_bytes: u64,
    pub min_single_query_size_bytes: u64,
    pub max_single_query_size_bytes: u64,
    pub hba_config: HbaConfig,
    pub webhook_auth_max_clock_skew_ms: u64,
    pub unsafe_enable_local_fs_connector: bool,
}
The section frontend in risingwave.toml.

Fields

max_total_query_size_bytes: u64

Total memory constraints for running queries.

min_single_query_size_bytes: u64

A query of size under this threshold will never be rejected due to memory constraints.

max_single_query_size_bytes: u64

A query of size exceeding this threshold will always be rejected due to memory constraints.

hba_config: HbaConfig

Host-based authentication configuration

webhook_auth_max_clock_skew_ms: u64

Maximum allowed clock skew in milliseconds for WebSocket ingest init authentication.

unsafe_enable_local_fs_connector: bool

Whether to allow local filesystem connectors such as posix_fs and fs. Disabled by default in release builds because these connectors can access files on the frontend host. Enabled by default in debug builds for local development.

Implementations